/* config.h */

/* RLaB system configuration header file. */

/* config.linux; This may be a good starting point */

#ifndef _CONFIG_H_
#define _CONFIG_H_

/*
 * Here we declare which header files the system has.
 */
#define HAVE_STDLIB_H
#define HAVE_TIME_H

/* If your compiler supports function protyping */
/*#define HAVE_PROTOTYPES*/
/*#define YY_USE_PROTOS*/

/* If your compiler supports (void *) */
/*#define HAVE_VOID_PTR*/

/* If your compiler supports const */
#define HAVE_CONST

/* If you libraries have a size_t type */
#define HAVE_SIZE_T

/* If your fseek() uses a SEEK_SET macro */
#define HAVE_SEEK_SET

/* If your system has <dirent.h>, as opposed to <sys/dir.h> */
#define HAVE_DIRENT

/* If your system has an index(3), and rindex(3) */
#define HAVE_INDEX

/* If your math library does not have rint() */
#define NO_RINT 

/* If your system has a difftime() function */
#define HAVE_DIFFTIME

/* This defines the byte significance of your machine */
#define LITTLE_ENDIAN
#undef BIG_ENDIAN

/*
 * If your system DOES NOT have an FOPEN_MAX defined.
 * FOPEN_MAX is the maximum number of files that
 * can be open at any one time.
 */

/* #define FOPEN_MAX  20 */

/*
 * If your system does not have a float.h, then try building, 
 * and running misc/enquire.c. Enquire will generate a suitable 
 * float.h. If you don't have, or can't build a float.h, then you
 * will need to define DBL_EPSILON.
 */

/* #define DBL_EPSILON 2.22e-16 */
#include <float.h>

/*
 * The width of your terminal. This will be replaced later on.
 */

#define TERM_WIDTH 72

/*
 * Here is where you tell RLaB how to deal with floating point
 * exceptions. 1st you need to tell us which header file declares
 * your floating point functions. If you are lucky, this is ieeefp.h
 */
#include <ieeefp.h>

/*
 * Next you need to tell us which floating point exceptions
 * you want to trap. If you don't know what to do here, then do:
 * `#define FP_SET_MASK ;' Then the defaults will be left alone.
 */
#define FP_SET_MASK ;

/*
 * The following tells RLaB how to handle math library errors.
 * `#undef USE_MATHERR'
 * `#define errcheck( a , b ) errno_check( a , b )'
 * will tell RLaB to check errno after every call to math library
 * functions. This method should work on any UNIX platform.
 *
 * `#define USE_MATHERR'
 * `#define errcheck( a , b )    a'
 * will tell RLaB to use matherr(). This is more efficient, since
 * matherr() is only called when an exception occurs. However
 * matherr() may not be available on BSD-style systems.
 */

/* #define USE_MATHERR */
#undef USE_MATHERR

#ifdef USE_MATHERR
#define errcheck( a , b )    a
#else
#define errcheck( a , b )    errno_check( a , b )
#endif

#endif /* _CONFIG_H_ */
