//-------------------------------------------------------------------//

//  Syntax:  whos ( L )

//  Description:

//  The whos function prints a tabular listing (to stderr) of the
//  global symbol-table contents, not including functions.

//  See Also: who, what

//-------------------------------------------------------------------//

static (whos_1, Btotal);

whos = function ( LIST )
{
  Btotal = 0;
  if (!exist (LIST)) { LIST = 0; }

  if (class (LIST) != "list") {
    whos_1 ($$);
  else
    whos_1 (LIST);
  } 
  fprintf ("stderr", "Total MBytes = %f\n", Btotal/1.e6);
};

whos_1 = function ( LIST )
{
  local (i, j, m, n, nbytes);

  fprintf ("stderr", "\n%s\tName\tClass\tSize\t\tNBytes\n", name (LIST));
  for (i in members (LIST))
  {
    if (class (LIST.[i]) != "function")
    {
      if (class (LIST.[i]) == "list") 
      {
        $self (LIST.[i]);
        fprintf ("stderr","\n");
      else
        if (class (LIST.[i]) == "string")
        {
      	  if ((n = LIST.[i].n) > 1)
      	  {
      	    nbytes = 0;
      	    for (j in 1:n)
      	    {
      	      nbytes = nbytes + length (LIST.[i][j]);
      	    }      	  
      	  else
              nbytes = length (LIST.[i]);
      	  }
          m = size (LIST.[i])[1]; 
          n = size (LIST.[i])[2];
          Btotal = Btotal + nbytes;
          fprintf ("stderr","\t%s\t%s\t%i\t%i\t%i\n", i, ...
      	      	    class(LIST.[i]), m, n, nbytes);
        else
          m = size (LIST.[i])[1]; 
          n = size (LIST.[i])[2];
          if (type (LIST.[i]) == "real")
          {
            nbytes = m*n*8;
          else
            nbytes = m*n*16;
          }
          Btotal = Btotal + nbytes;
          fprintf ("stderr","\t%s\t%s\t%i\t%i\t%i\n", i, ...
                   class (LIST.[i]), m, n, nbytes);
        }
      }
    }
  }
};
